@@ -870,3 +870,65 @@ def get_q_surf(eqm, qvalue=1., t_in=None, coord_out='rho_tor'):
             rho_surf[j] = q_surf
 
     return np.squeeze(rho_surf)
+
+
+def to_geqdsk(eqm, t_in=0.):
+    """
+    Parameters
+    ----------
+    eqm: instance of aug_sfutils.sf2equ.EQU
+    t_in : float
+        Time in seconds.
+
+    Returns
+    -------
+    dict :
+        Dictionary containing CLISTE results in OMFIT geqdsk format.
+        Note that this dictionary does not contain yet all processed results typical of 
+        omfit_classes.omfit_eqdsk.OMFITgeqdsk objects.
+    """
+
+    equ = coco2coco(eqm, cocos_out=1)
+
+    jt = np.argmin(equ.time - t_in)
+
+    psi_in  = equ.pfl[jt]
+
+    geq = {}
+
+    geq['CASE'] = np.array(['  CLISTE ', '    ', '   ', ' #' + str(equ.shot), '  %.2fs' % t_in, '  ' + 'EQI'], dtype='<U8')
+    
+    # separatrix R and Z
+    geq['RBBBS'], geq['ZBBBS'] = sf.rho2rz(equ, 0.999, t_in=equ.time[jt], all_lines=False)
+
+    # R,Z of limiter structures
+    geq['RLIM'] = [1.035, 1.050, 1.090, 1.140, 1.235, 1.340, 1.430, 1.505, 1.630, 1.770, 1.970, 2.110, 2.170, 2.205, 2.210, 2.175, 2.130, 2.010, 1.890, 1.705, 1.645, 1.580, 1.458, 1.325, 1.235, 1.286, 1.280, 1.245, 1.125, 1.060, 1.035]
+
+    geq['ZLIM'] = [0.000, 0.250, 0.500, 0.700, 0.965, 1.100, 1.150, 1.190, 1.150, 1.085, 0.780, 0.540, 0.390, 0.210, 0.000, -0.150, -0.280, -0.500, -0.680, -0.860, -0.966, -1.208, -1.060, -1.060, -1.126, -0.976, -0.892, -0.820, -0.634, -0.300, 0.000]
+
+    geq['NW'] = len(equ.Rmesh)
+    geq['NH'] = len(equ.Zmesh)
+    
+    geq['RLEFT']   = equ.Rmesh[0]
+    geq['RDIM']    = equ.Rmesh[-1] - equ.Rmesh[0]
+    geq['ZDIM']    = equ.Zmesh[-1] - equ.Zmesh[0]
+    geq['RMAXIS']  = equ.Rmag[jt]
+    geq['ZMAXIS']  = equ.Zmag[jt]
+    geq['SIMAG']   = psi_in[0]
+    geq['SIBRY']   = psi_in[-1]
+    geq['CURRENT'] = equ.ip[jt]
+    geq['BCENTR']  = equ.B0[jt]
+    geq['RCENTR']  = equ.R0  ##[jt]   # TODO this seems to be time-independent?
+    geq['ZMID']    = 0.5*(equ.Zmesh[-1] + equ.Zmesh[0])
+    geq['PSIRZ']   = equ.pfm[jt]
+
+    # Interpolate onto an equidistant Psi-grid
+    psi_grid = np.linspace(psi_in[0], psi_in[-1], len(equ.Rmesh))
+
+    geq['QPSI']   = np.interp(psi_grid, psi_in, equ.q[jt])
+    geq['PRES']   = np.interp(psi_grid, psi_in, equ.pres[jt])
+    geq['PPRIME'] = np.interp(psi_grid, psi_in, equ.dpres[jt])
+    geq['FPOL']   = np.interp(psi_grid, psi_in, 2.e-7*equ.jpol[jt] )
+    geq['FFPRIM'] = np.interp(psi_grid, psi_in, -2*np.pi*equ.ffp[jt])
+
+    return geq
