@@ -2,7 +2,7 @@ import os, datetime, logging
 from struct import unpack
 import numpy as np
 
-from aug_sfutils import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc, getlastshot
+from aug_sfutils import sfdics, sfh_rw, sfobj, manage_ed, parse_kwargs, str_byt, libddc, getlastshot
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
@@ -144,7 +144,7 @@ class SFREAD:
                 if len(byt_str) < 128:
                     logger.error('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
                     return
-                self.sfh = sfhread.read_sfh(byt_str)
+                self.sfh = sfh_rw.read_sfh(byt_str)
                 self.status = True
         else:
             logger.error('Shotfile %s not found' %self.sfile)
@@ -369,8 +369,21 @@ class SFREAD:
                 if j == 0:
                     dout = data*1. # Creates a copy of a read-only array, only once
                     dout.calib = True
-                dout *= pscal[mult] # it can have size > 1
-                dout += pscal[shif]
+                multi = np.atleast_1d(pscal[mult])
+                shift = np.atleast_1d(pscal[shif])
+                if data.obj_type == 7 or len(multi) == 1:
+                    dout *= multi[0] # MXR
+                    dout += shift[0]
+                else:
+                    n_pars = dout.shape[1]
+                    if n_pars != len(multi):
+                        logger.warning('Inconsitent sizes in calibration PSet %s', obj)
+                    if n_pars <= len(multi):
+                        dout *= multi[: n_pars] # BLB
+                        dout += shift[: n_pars]
+                    else:
+                        dout *= multi[0]
+                        dout += shift[0]
             else:
                 break
         if 'dout' in locals():
