@@ -314,7 +314,7 @@ class WW:
                     sizes[1] = sizes[2]
             else:
                 nt = 1
-            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, sizes[:3])
+            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, sizes[0], sizes[1], sizes[2])
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
             lname  = ct.c_uint64(len(areaname))
